@@ -5,6 +5,7 @@
 '''
 
 import numpy as np
+from keyname import keyname as kn
 import os
 import pytest
 import seaborn as sns
@@ -123,3 +124,33 @@ def test_outpath():
         assert os.path.exists(
             f'teeplots/mydirectory/additional=metadata+viz=lineplot+ext={ext}.meta',
         )
+
+def test_longname():
+
+    # adapted from https://seaborn.pydata.org/generated/seaborn.lineplot.html
+    np.random.seed(1)
+    x, y = np.random.normal(size=(2, 5000)).cumsum(axis=1)
+
+    tp.tee(
+        sns.lineplot,
+        x=x,
+        y=y,
+        sort=False,
+        lw=1,
+        teeplot_outattrs={
+          f'additional{i}' : 'metadata'
+          for i in range(100)
+        },
+    )
+
+    for ext in '.pdf', '.png':
+        assert os.path.exists(
+            kn.chop(
+                f'''teeplots/{
+                    kn.pack({
+                      f'additional{i}' : 'metadata'
+                      for i in range(100)
+                    })
+                }+viz=lineplot+ext={ext}''',
+            )
+        )
